# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_clientserver_uds.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_clientserver_uds.proto',
  package='',
  syntax='proto2',
  serialized_options=b'H\001\220\001\000',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$steammessages_clientserver_uds.proto\x1a\x18steammessages_base.proto\"G\n\x1e\x43MsgClientUDSP2PSessionStarted\x12\x16\n\x0esteamid_remote\x18\x01 \x01(\x06\x12\r\n\x05\x61ppid\x18\x02 \x01(\x05\"\x81\x02\n\x1c\x43MsgClientUDSP2PSessionEnded\x12\x16\n\x0esteamid_remote\x18\x01 \x01(\x06\x12\r\n\x05\x61ppid\x18\x02 \x01(\x05\x12\x1a\n\x12session_length_sec\x18\x03 \x01(\x05\x12\x15\n\rsession_error\x18\x04 \x01(\x05\x12\x0f\n\x07nattype\x18\x05 \x01(\x05\x12\x12\n\nbytes_recv\x18\x06 \x01(\x05\x12\x12\n\nbytes_sent\x18\x07 \x01(\x05\x12\x18\n\x10\x62ytes_sent_relay\x18\x08 \x01(\x05\x12\x18\n\x10\x62ytes_recv_relay\x18\t \x01(\x05\x12\x1a\n\x12time_to_connect_ms\x18\n \x01(\x05\"\x1c\n\x1a\x43MsgClientGetClientDetails\"\xdb\x02\n\"CMsgClientGetClientDetailsResponse\x12\x17\n\x0fpackage_version\x18\x01 \x01(\r\x12\n\n\x02os\x18\x02 \x01(\t\x12\x14\n\x0cmachine_name\x18\x03 \x01(\t\x12\x11\n\tip_public\x18\x04 \x01(\t\x12\x12\n\nip_private\x18\x05 \x01(\t\x12?\n\rgames_running\x18\x06 \x03(\x0b\x32(.CMsgClientGetClientDetailsResponse.Game\x12\x17\n\x0f\x62ytes_available\x18\x07 \x01(\x04\x12\x18\n\x10protocol_version\x18\x08 \x01(\r\x12\x1a\n\x12\x63lientcomm_version\x18\t \x01(\r\x1a\x43\n\x04Game\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x12\n\nextra_info\x18\x02 \x01(\t\x12\x18\n\x10time_running_sec\x18\x03 \x01(\r\"\xa5\x01\n\x1a\x43MsgClientGetClientAppList\x12\r\n\x05media\x18\x01 \x01(\x08\x12\r\n\x05tools\x18\x02 \x01(\x08\x12\r\n\x05games\x18\x03 \x01(\x08\x12\x16\n\x0eonly_installed\x18\x04 \x01(\x08\x12\x15\n\ronly_changing\x18\x05 \x01(\x08\x12\x0e\n\x06\x63omics\x18\x06 \x01(\x08\x12\x1b\n\x13include_client_info\x18\x07 \x01(\x08\"\xb4\x06\n\"CMsgClientGetClientAppListResponse\x12\x35\n\x04\x61pps\x18\x01 \x03(\x0b\x32\'.CMsgClientGetClientAppListResponse.App\x12\x17\n\x0f\x62ytes_available\x18\x02 \x01(\x04\x12\x38\n\x0b\x63lient_info\x18\x03 \x01(\x0b\x32#.CMsgClientGetClientDetailsResponse\x1a\x83\x05\n\x03\x41pp\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x10\n\x08\x63\x61tegory\x18\x02 \x01(\t\x12\x10\n\x08\x61pp_type\x18\n \x01(\t\x12\x10\n\x08\x66\x61vorite\x18\x03 \x01(\x08\x12\x11\n\tinstalled\x18\x04 \x01(\x08\x12\x13\n\x0b\x61uto_update\x18\x05 \x01(\x08\x12\x18\n\x10\x62ytes_downloaded\x18\x06 \x01(\x04\x12\x19\n\x11\x62ytes_to_download\x18\x07 \x01(\x04\x12\x1b\n\x13\x62ytes_download_rate\x18\x08 \x01(\r\x12\x39\n\x04\x64lcs\x18\t \x03(\x0b\x32+.CMsgClientGetClientAppListResponse.App.DLC\x12\x17\n\x0f\x64ownload_paused\x18\x0b \x01(\x08\x12\x17\n\x0fnum_downloading\x18\x0c \x01(\r\x12\x12\n\nnum_paused\x18\r \x01(\r\x12\x10\n\x08\x63hanging\x18\x0e \x01(\x08\x12\x1d\n\x15\x61vailable_on_platform\x18\x0f \x01(\x08\x12\x14\n\x0c\x62ytes_staged\x18\x10 \x01(\x04\x12\x16\n\x0e\x62ytes_to_stage\x18\x11 \x01(\x04\x12\x16\n\x0e\x62ytes_required\x18\x12 \x01(\x04\x12\x16\n\x0esource_buildid\x18\x13 \x01(\r\x12\x16\n\x0etarget_buildid\x18\x14 \x01(\r\x12#\n\x1b\x65stimated_seconds_remaining\x18\x15 \x01(\r\x12\x16\n\x0equeue_position\x18\x16 \x01(\x05\x12\x14\n\x0cuninstalling\x18\x17 \x01(\x08\x12\x19\n\x11rt_time_scheduled\x18\x18 \x01(\r\x1a\'\n\x03\x44LC\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x11\n\tinstalled\x18\x02 \x01(\x08\"+\n\x1a\x43MsgClientInstallClientApp\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"4\n\"CMsgClientInstallClientAppResponse\x12\x0e\n\x06result\x18\x01 \x01(\r\"-\n\x1c\x43MsgClientUninstallClientApp\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\"6\n$CMsgClientUninstallClientAppResponse\x12\x0e\n\x06result\x18\x01 \x01(\r\"B\n!CMsgClientSetClientAppUpdateState\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x0e\n\x06update\x18\x02 \x01(\x08\";\n)CMsgClientSetClientAppUpdateStateResponse\x12\x0e\n\x06result\x18\x01 \x01(\r\"4\n\"CMsgClientEnableOrDisableDownloads\x12\x0e\n\x06\x65nable\x18\x01 \x01(\x08\"<\n*CMsgClientEnableOrDisableDownloadsResponse\x12\x0e\n\x06result\x18\x01 \x01(\rB\x05H\x01\x90\x01\x00'
  ,
  dependencies=[steammessages__base__pb2.DESCRIPTOR,])




_CMSGCLIENTUDSP2PSESSIONSTARTED = _descriptor.Descriptor(
  name='CMsgClientUDSP2PSessionStarted',
  full_name='CMsgClientUDSP2PSessionStarted',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid_remote', full_name='CMsgClientUDSP2PSessionStarted.steamid_remote', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CMsgClientUDSP2PSessionStarted.appid', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=66,
  serialized_end=137,
)


_CMSGCLIENTUDSP2PSESSIONENDED = _descriptor.Descriptor(
  name='CMsgClientUDSP2PSessionEnded',
  full_name='CMsgClientUDSP2PSessionEnded',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid_remote', full_name='CMsgClientUDSP2PSessionEnded.steamid_remote', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CMsgClientUDSP2PSessionEnded.appid', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_length_sec', full_name='CMsgClientUDSP2PSessionEnded.session_length_sec', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_error', full_name='CMsgClientUDSP2PSessionEnded.session_error', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nattype', full_name='CMsgClientUDSP2PSessionEnded.nattype', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes_recv', full_name='CMsgClientUDSP2PSessionEnded.bytes_recv', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes_sent', full_name='CMsgClientUDSP2PSessionEnded.bytes_sent', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes_sent_relay', full_name='CMsgClientUDSP2PSessionEnded.bytes_sent_relay', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes_recv_relay', full_name='CMsgClientUDSP2PSessionEnded.bytes_recv_relay', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_to_connect_ms', full_name='CMsgClientUDSP2PSessionEnded.time_to_connect_ms', index=9,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=140,
  serialized_end=397,
)


_CMSGCLIENTGETCLIENTDETAILS = _descriptor.Descriptor(
  name='CMsgClientGetClientDetails',
  full_name='CMsgClientGetClientDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=399,
  serialized_end=427,
)


_CMSGCLIENTGETCLIENTDETAILSRESPONSE_GAME = _descriptor.Descriptor(
  name='Game',
  full_name='CMsgClientGetClientDetailsResponse.Game',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CMsgClientGetClientDetailsResponse.Game.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extra_info', full_name='CMsgClientGetClientDetailsResponse.Game.extra_info', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_running_sec', full_name='CMsgClientGetClientDetailsResponse.Game.time_running_sec', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=710,
  serialized_end=777,
)

_CMSGCLIENTGETCLIENTDETAILSRESPONSE = _descriptor.Descriptor(
  name='CMsgClientGetClientDetailsResponse',
  full_name='CMsgClientGetClientDetailsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='package_version', full_name='CMsgClientGetClientDetailsResponse.package_version', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='os', full_name='CMsgClientGetClientDetailsResponse.os', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='machine_name', full_name='CMsgClientGetClientDetailsResponse.machine_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip_public', full_name='CMsgClientGetClientDetailsResponse.ip_public', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip_private', full_name='CMsgClientGetClientDetailsResponse.ip_private', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='games_running', full_name='CMsgClientGetClientDetailsResponse.games_running', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes_available', full_name='CMsgClientGetClientDetailsResponse.bytes_available', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protocol_version', full_name='CMsgClientGetClientDetailsResponse.protocol_version', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clientcomm_version', full_name='CMsgClientGetClientDetailsResponse.clientcomm_version', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTGETCLIENTDETAILSRESPONSE_GAME, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=430,
  serialized_end=777,
)


_CMSGCLIENTGETCLIENTAPPLIST = _descriptor.Descriptor(
  name='CMsgClientGetClientAppList',
  full_name='CMsgClientGetClientAppList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='media', full_name='CMsgClientGetClientAppList.media', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tools', full_name='CMsgClientGetClientAppList.tools', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='games', full_name='CMsgClientGetClientAppList.games', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='only_installed', full_name='CMsgClientGetClientAppList.only_installed', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='only_changing', full_name='CMsgClientGetClientAppList.only_changing', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='comics', full_name='CMsgClientGetClientAppList.comics', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_client_info', full_name='CMsgClientGetClientAppList.include_client_info', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=780,
  serialized_end=945,
)


_CMSGCLIENTGETCLIENTAPPLISTRESPONSE_APP_DLC = _descriptor.Descriptor(
  name='DLC',
  full_name='CMsgClientGetClientAppListResponse.App.DLC',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CMsgClientGetClientAppListResponse.App.DLC.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='installed', full_name='CMsgClientGetClientAppListResponse.App.DLC.installed', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1729,
  serialized_end=1768,
)

_CMSGCLIENTGETCLIENTAPPLISTRESPONSE_APP = _descriptor.Descriptor(
  name='App',
  full_name='CMsgClientGetClientAppListResponse.App',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CMsgClientGetClientAppListResponse.App.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='category', full_name='CMsgClientGetClientAppListResponse.App.category', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_type', full_name='CMsgClientGetClientAppListResponse.App.app_type', index=2,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='favorite', full_name='CMsgClientGetClientAppListResponse.App.favorite', index=3,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='installed', full_name='CMsgClientGetClientAppListResponse.App.installed', index=4,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_update', full_name='CMsgClientGetClientAppListResponse.App.auto_update', index=5,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes_downloaded', full_name='CMsgClientGetClientAppListResponse.App.bytes_downloaded', index=6,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes_to_download', full_name='CMsgClientGetClientAppListResponse.App.bytes_to_download', index=7,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes_download_rate', full_name='CMsgClientGetClientAppListResponse.App.bytes_download_rate', index=8,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dlcs', full_name='CMsgClientGetClientAppListResponse.App.dlcs', index=9,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='download_paused', full_name='CMsgClientGetClientAppListResponse.App.download_paused', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_downloading', full_name='CMsgClientGetClientAppListResponse.App.num_downloading', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_paused', full_name='CMsgClientGetClientAppListResponse.App.num_paused', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='changing', full_name='CMsgClientGetClientAppListResponse.App.changing', index=13,
      number=14, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='available_on_platform', full_name='CMsgClientGetClientAppListResponse.App.available_on_platform', index=14,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes_staged', full_name='CMsgClientGetClientAppListResponse.App.bytes_staged', index=15,
      number=16, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes_to_stage', full_name='CMsgClientGetClientAppListResponse.App.bytes_to_stage', index=16,
      number=17, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes_required', full_name='CMsgClientGetClientAppListResponse.App.bytes_required', index=17,
      number=18, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_buildid', full_name='CMsgClientGetClientAppListResponse.App.source_buildid', index=18,
      number=19, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_buildid', full_name='CMsgClientGetClientAppListResponse.App.target_buildid', index=19,
      number=20, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='estimated_seconds_remaining', full_name='CMsgClientGetClientAppListResponse.App.estimated_seconds_remaining', index=20,
      number=21, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='queue_position', full_name='CMsgClientGetClientAppListResponse.App.queue_position', index=21,
      number=22, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='uninstalling', full_name='CMsgClientGetClientAppListResponse.App.uninstalling', index=22,
      number=23, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rt_time_scheduled', full_name='CMsgClientGetClientAppListResponse.App.rt_time_scheduled', index=23,
      number=24, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTGETCLIENTAPPLISTRESPONSE_APP_DLC, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1125,
  serialized_end=1768,
)

_CMSGCLIENTGETCLIENTAPPLISTRESPONSE = _descriptor.Descriptor(
  name='CMsgClientGetClientAppListResponse',
  full_name='CMsgClientGetClientAppListResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='apps', full_name='CMsgClientGetClientAppListResponse.apps', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bytes_available', full_name='CMsgClientGetClientAppListResponse.bytes_available', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_info', full_name='CMsgClientGetClientAppListResponse.client_info', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTGETCLIENTAPPLISTRESPONSE_APP, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=948,
  serialized_end=1768,
)


_CMSGCLIENTINSTALLCLIENTAPP = _descriptor.Descriptor(
  name='CMsgClientInstallClientApp',
  full_name='CMsgClientInstallClientApp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CMsgClientInstallClientApp.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1770,
  serialized_end=1813,
)


_CMSGCLIENTINSTALLCLIENTAPPRESPONSE = _descriptor.Descriptor(
  name='CMsgClientInstallClientAppResponse',
  full_name='CMsgClientInstallClientAppResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgClientInstallClientAppResponse.result', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1815,
  serialized_end=1867,
)


_CMSGCLIENTUNINSTALLCLIENTAPP = _descriptor.Descriptor(
  name='CMsgClientUninstallClientApp',
  full_name='CMsgClientUninstallClientApp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CMsgClientUninstallClientApp.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1869,
  serialized_end=1914,
)


_CMSGCLIENTUNINSTALLCLIENTAPPRESPONSE = _descriptor.Descriptor(
  name='CMsgClientUninstallClientAppResponse',
  full_name='CMsgClientUninstallClientAppResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgClientUninstallClientAppResponse.result', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1916,
  serialized_end=1970,
)


_CMSGCLIENTSETCLIENTAPPUPDATESTATE = _descriptor.Descriptor(
  name='CMsgClientSetClientAppUpdateState',
  full_name='CMsgClientSetClientAppUpdateState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CMsgClientSetClientAppUpdateState.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update', full_name='CMsgClientSetClientAppUpdateState.update', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1972,
  serialized_end=2038,
)


_CMSGCLIENTSETCLIENTAPPUPDATESTATERESPONSE = _descriptor.Descriptor(
  name='CMsgClientSetClientAppUpdateStateResponse',
  full_name='CMsgClientSetClientAppUpdateStateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgClientSetClientAppUpdateStateResponse.result', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2040,
  serialized_end=2099,
)


_CMSGCLIENTENABLEORDISABLEDOWNLOADS = _descriptor.Descriptor(
  name='CMsgClientEnableOrDisableDownloads',
  full_name='CMsgClientEnableOrDisableDownloads',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enable', full_name='CMsgClientEnableOrDisableDownloads.enable', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2101,
  serialized_end=2153,
)


_CMSGCLIENTENABLEORDISABLEDOWNLOADSRESPONSE = _descriptor.Descriptor(
  name='CMsgClientEnableOrDisableDownloadsResponse',
  full_name='CMsgClientEnableOrDisableDownloadsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgClientEnableOrDisableDownloadsResponse.result', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2155,
  serialized_end=2215,
)

_CMSGCLIENTGETCLIENTDETAILSRESPONSE_GAME.containing_type = _CMSGCLIENTGETCLIENTDETAILSRESPONSE
_CMSGCLIENTGETCLIENTDETAILSRESPONSE.fields_by_name['games_running'].message_type = _CMSGCLIENTGETCLIENTDETAILSRESPONSE_GAME
_CMSGCLIENTGETCLIENTAPPLISTRESPONSE_APP_DLC.containing_type = _CMSGCLIENTGETCLIENTAPPLISTRESPONSE_APP
_CMSGCLIENTGETCLIENTAPPLISTRESPONSE_APP.fields_by_name['dlcs'].message_type = _CMSGCLIENTGETCLIENTAPPLISTRESPONSE_APP_DLC
_CMSGCLIENTGETCLIENTAPPLISTRESPONSE_APP.containing_type = _CMSGCLIENTGETCLIENTAPPLISTRESPONSE
_CMSGCLIENTGETCLIENTAPPLISTRESPONSE.fields_by_name['apps'].message_type = _CMSGCLIENTGETCLIENTAPPLISTRESPONSE_APP
_CMSGCLIENTGETCLIENTAPPLISTRESPONSE.fields_by_name['client_info'].message_type = _CMSGCLIENTGETCLIENTDETAILSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientUDSP2PSessionStarted'] = _CMSGCLIENTUDSP2PSESSIONSTARTED
DESCRIPTOR.message_types_by_name['CMsgClientUDSP2PSessionEnded'] = _CMSGCLIENTUDSP2PSESSIONENDED
DESCRIPTOR.message_types_by_name['CMsgClientGetClientDetails'] = _CMSGCLIENTGETCLIENTDETAILS
DESCRIPTOR.message_types_by_name['CMsgClientGetClientDetailsResponse'] = _CMSGCLIENTGETCLIENTDETAILSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientGetClientAppList'] = _CMSGCLIENTGETCLIENTAPPLIST
DESCRIPTOR.message_types_by_name['CMsgClientGetClientAppListResponse'] = _CMSGCLIENTGETCLIENTAPPLISTRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientInstallClientApp'] = _CMSGCLIENTINSTALLCLIENTAPP
DESCRIPTOR.message_types_by_name['CMsgClientInstallClientAppResponse'] = _CMSGCLIENTINSTALLCLIENTAPPRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientUninstallClientApp'] = _CMSGCLIENTUNINSTALLCLIENTAPP
DESCRIPTOR.message_types_by_name['CMsgClientUninstallClientAppResponse'] = _CMSGCLIENTUNINSTALLCLIENTAPPRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientSetClientAppUpdateState'] = _CMSGCLIENTSETCLIENTAPPUPDATESTATE
DESCRIPTOR.message_types_by_name['CMsgClientSetClientAppUpdateStateResponse'] = _CMSGCLIENTSETCLIENTAPPUPDATESTATERESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientEnableOrDisableDownloads'] = _CMSGCLIENTENABLEORDISABLEDOWNLOADS
DESCRIPTOR.message_types_by_name['CMsgClientEnableOrDisableDownloadsResponse'] = _CMSGCLIENTENABLEORDISABLEDOWNLOADSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CMsgClientUDSP2PSessionStarted = _reflection.GeneratedProtocolMessageType('CMsgClientUDSP2PSessionStarted', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTUDSP2PSESSIONSTARTED,
  '__module__' : 'steammessages_clientserver_uds_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUDSP2PSessionStarted)
  })
_sym_db.RegisterMessage(CMsgClientUDSP2PSessionStarted)

CMsgClientUDSP2PSessionEnded = _reflection.GeneratedProtocolMessageType('CMsgClientUDSP2PSessionEnded', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTUDSP2PSESSIONENDED,
  '__module__' : 'steammessages_clientserver_uds_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUDSP2PSessionEnded)
  })
_sym_db.RegisterMessage(CMsgClientUDSP2PSessionEnded)

CMsgClientGetClientDetails = _reflection.GeneratedProtocolMessageType('CMsgClientGetClientDetails', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTGETCLIENTDETAILS,
  '__module__' : 'steammessages_clientserver_uds_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientGetClientDetails)
  })
_sym_db.RegisterMessage(CMsgClientGetClientDetails)

CMsgClientGetClientDetailsResponse = _reflection.GeneratedProtocolMessageType('CMsgClientGetClientDetailsResponse', (_message.Message,), {

  'Game' : _reflection.GeneratedProtocolMessageType('Game', (_message.Message,), {
    'DESCRIPTOR' : _CMSGCLIENTGETCLIENTDETAILSRESPONSE_GAME,
    '__module__' : 'steammessages_clientserver_uds_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientGetClientDetailsResponse.Game)
    })
  ,
  'DESCRIPTOR' : _CMSGCLIENTGETCLIENTDETAILSRESPONSE,
  '__module__' : 'steammessages_clientserver_uds_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientGetClientDetailsResponse)
  })
_sym_db.RegisterMessage(CMsgClientGetClientDetailsResponse)
_sym_db.RegisterMessage(CMsgClientGetClientDetailsResponse.Game)

CMsgClientGetClientAppList = _reflection.GeneratedProtocolMessageType('CMsgClientGetClientAppList', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTGETCLIENTAPPLIST,
  '__module__' : 'steammessages_clientserver_uds_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientGetClientAppList)
  })
_sym_db.RegisterMessage(CMsgClientGetClientAppList)

CMsgClientGetClientAppListResponse = _reflection.GeneratedProtocolMessageType('CMsgClientGetClientAppListResponse', (_message.Message,), {

  'App' : _reflection.GeneratedProtocolMessageType('App', (_message.Message,), {

    'DLC' : _reflection.GeneratedProtocolMessageType('DLC', (_message.Message,), {
      'DESCRIPTOR' : _CMSGCLIENTGETCLIENTAPPLISTRESPONSE_APP_DLC,
      '__module__' : 'steammessages_clientserver_uds_pb2'
      # @@protoc_insertion_point(class_scope:CMsgClientGetClientAppListResponse.App.DLC)
      })
    ,
    'DESCRIPTOR' : _CMSGCLIENTGETCLIENTAPPLISTRESPONSE_APP,
    '__module__' : 'steammessages_clientserver_uds_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientGetClientAppListResponse.App)
    })
  ,
  'DESCRIPTOR' : _CMSGCLIENTGETCLIENTAPPLISTRESPONSE,
  '__module__' : 'steammessages_clientserver_uds_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientGetClientAppListResponse)
  })
_sym_db.RegisterMessage(CMsgClientGetClientAppListResponse)
_sym_db.RegisterMessage(CMsgClientGetClientAppListResponse.App)
_sym_db.RegisterMessage(CMsgClientGetClientAppListResponse.App.DLC)

CMsgClientInstallClientApp = _reflection.GeneratedProtocolMessageType('CMsgClientInstallClientApp', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTINSTALLCLIENTAPP,
  '__module__' : 'steammessages_clientserver_uds_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientInstallClientApp)
  })
_sym_db.RegisterMessage(CMsgClientInstallClientApp)

CMsgClientInstallClientAppResponse = _reflection.GeneratedProtocolMessageType('CMsgClientInstallClientAppResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTINSTALLCLIENTAPPRESPONSE,
  '__module__' : 'steammessages_clientserver_uds_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientInstallClientAppResponse)
  })
_sym_db.RegisterMessage(CMsgClientInstallClientAppResponse)

CMsgClientUninstallClientApp = _reflection.GeneratedProtocolMessageType('CMsgClientUninstallClientApp', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTUNINSTALLCLIENTAPP,
  '__module__' : 'steammessages_clientserver_uds_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUninstallClientApp)
  })
_sym_db.RegisterMessage(CMsgClientUninstallClientApp)

CMsgClientUninstallClientAppResponse = _reflection.GeneratedProtocolMessageType('CMsgClientUninstallClientAppResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTUNINSTALLCLIENTAPPRESPONSE,
  '__module__' : 'steammessages_clientserver_uds_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUninstallClientAppResponse)
  })
_sym_db.RegisterMessage(CMsgClientUninstallClientAppResponse)

CMsgClientSetClientAppUpdateState = _reflection.GeneratedProtocolMessageType('CMsgClientSetClientAppUpdateState', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTSETCLIENTAPPUPDATESTATE,
  '__module__' : 'steammessages_clientserver_uds_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientSetClientAppUpdateState)
  })
_sym_db.RegisterMessage(CMsgClientSetClientAppUpdateState)

CMsgClientSetClientAppUpdateStateResponse = _reflection.GeneratedProtocolMessageType('CMsgClientSetClientAppUpdateStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTSETCLIENTAPPUPDATESTATERESPONSE,
  '__module__' : 'steammessages_clientserver_uds_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientSetClientAppUpdateStateResponse)
  })
_sym_db.RegisterMessage(CMsgClientSetClientAppUpdateStateResponse)

CMsgClientEnableOrDisableDownloads = _reflection.GeneratedProtocolMessageType('CMsgClientEnableOrDisableDownloads', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTENABLEORDISABLEDOWNLOADS,
  '__module__' : 'steammessages_clientserver_uds_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientEnableOrDisableDownloads)
  })
_sym_db.RegisterMessage(CMsgClientEnableOrDisableDownloads)

CMsgClientEnableOrDisableDownloadsResponse = _reflection.GeneratedProtocolMessageType('CMsgClientEnableOrDisableDownloadsResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTENABLEORDISABLEDOWNLOADSRESPONSE,
  '__module__' : 'steammessages_clientserver_uds_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientEnableOrDisableDownloadsResponse)
  })
_sym_db.RegisterMessage(CMsgClientEnableOrDisableDownloadsResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_offline.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2
import steam.protobufs.offline_ticket_pb2 as offline__ticket__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_offline.proto',
  package='',
  syntax='proto2',
  serialized_options=b'\220\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1bsteammessages_offline.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\x1a\x14offline_ticket.proto\"V\n&COffline_GetOfflineLogonTicket_Request\x12\x10\n\x08priority\x18\x01 \x01(\r\x12\x1a\n\x12perform_encryption\x18\x02 \x01(\x08\"\x82\x01\n\'COffline_GetOfflineLogonTicket_Response\x12\x19\n\x11serialized_ticket\x18\x01 \x01(\x0c\x12\x11\n\tsignature\x18\x02 \x01(\x0c\x12)\n\x10\x65ncrypted_ticket\x18\x03 \x01(\x0b\x32\x0f.Offline_Ticket\"0\n.COffline_GetUnsignedOfflineLogonTicket_Request\"O\n\x1b\x43Offline_OfflineLogonTicket\x12\x11\n\taccountid\x18\x01 \x01(\r\x12\x1d\n\x15rtime32_creation_time\x18\x02 \x01(\x07\"_\n/COffline_GetUnsignedOfflineLogonTicket_Response\x12,\n\x06ticket\x18\x01 \x01(\x0b\x32\x1c.COffline_OfflineLogonTicket2\xa3\x03\n\x07Offline\x12\xb5\x01\n\x15GetOfflineLogonTicket\x12\'.COffline_GetOfflineLogonTicket_Request\x1a(.COffline_GetOfflineLogonTicket_Response\"I\x82\xb5\x18\x45Get a serialized and signed offline logon ticket for the current user\x12\xc1\x01\n\x1dGetUnsignedOfflineLogonTicket\x12/.COffline_GetUnsignedOfflineLogonTicket_Request\x1a\x30.COffline_GetUnsignedOfflineLogonTicket_Response\"=\x82\xb5\x18\x39Get an unsigned offline logon ticket for the current user\x1a\x1c\x82\xb5\x18\x18Offline settings serviceB\x03\x90\x01\x01'
  ,
  dependencies=[steammessages__base__pb2.DESCRIPTOR,steammessages__unified__base__pb2.DESCRIPTOR,offline__ticket__pb2.DESCRIPTOR,])




_COFFLINE_GETOFFLINELOGONTICKET_REQUEST = _descriptor.Descriptor(
  name='COffline_GetOfflineLogonTicket_Request',
  full_name='COffline_GetOfflineLogonTicket_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='priority', full_name='COffline_GetOfflineLogonTicket_Request.priority', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='perform_encryption', full_name='COffline_GetOfflineLogonTicket_Request.perform_encryption', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=113,
  serialized_end=199,
)


_COFFLINE_GETOFFLINELOGONTICKET_RESPONSE = _descriptor.Descriptor(
  name='COffline_GetOfflineLogonTicket_Response',
  full_name='COffline_GetOfflineLogonTicket_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='serialized_ticket', full_name='COffline_GetOfflineLogonTicket_Response.serialized_ticket', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signature', full_name='COffline_GetOfflineLogonTicket_Response.signature', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='encrypted_ticket', full_name='COffline_GetOfflineLogonTicket_Response.encrypted_ticket', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=202,
  serialized_end=332,
)


_COFFLINE_GETUNSIGNEDOFFLINELOGONTICKET_REQUEST = _descriptor.Descriptor(
  name='COffline_GetUnsignedOfflineLogonTicket_Request',
  full_name='COffline_GetUnsignedOfflineLogonTicket_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=334,
  serialized_end=382,
)


_COFFLINE_OFFLINELOGONTICKET = _descriptor.Descriptor(
  name='COffline_OfflineLogonTicket',
  full_name='COffline_OfflineLogonTicket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='accountid', full_name='COffline_OfflineLogonTicket.accountid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rtime32_creation_time', full_name='COffline_OfflineLogonTicket.rtime32_creation_time', index=1,
      number=2, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=384,
  serialized_end=463,
)


_COFFLINE_GETUNSIGNEDOFFLINELOGONTICKET_RESPONSE = _descriptor.Descriptor(
  name='COffline_GetUnsignedOfflineLogonTicket_Response',
  full_name='COffline_GetUnsignedOfflineLogonTicket_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ticket', full_name='COffline_GetUnsignedOfflineLogonTicket_Response.ticket', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=465,
  serialized_end=560,
)

_COFFLINE_GETOFFLINELOGONTICKET_RESPONSE.fields_by_name['encrypted_ticket'].message_type = offline__ticket__pb2._OFFLINE_TICKET
_COFFLINE_GETUNSIGNEDOFFLINELOGONTICKET_RESPONSE.fields_by_name['ticket'].message_type = _COFFLINE_OFFLINELOGONTICKET
DESCRIPTOR.message_types_by_name['COffline_GetOfflineLogonTicket_Request'] = _COFFLINE_GETOFFLINELOGONTICKET_REQUEST
DESCRIPTOR.message_types_by_name['COffline_GetOfflineLogonTicket_Response'] = _COFFLINE_GETOFFLINELOGONTICKET_RESPONSE
DESCRIPTOR.message_types_by_name['COffline_GetUnsignedOfflineLogonTicket_Request'] = _COFFLINE_GETUNSIGNEDOFFLINELOGONTICKET_REQUEST
DESCRIPTOR.message_types_by_name['COffline_OfflineLogonTicket'] = _COFFLINE_OFFLINELOGONTICKET
DESCRIPTOR.message_types_by_name['COffline_GetUnsignedOfflineLogonTicket_Response'] = _COFFLINE_GETUNSIGNEDOFFLINELOGONTICKET_RESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

COffline_GetOfflineLogonTicket_Request = _reflection.GeneratedProtocolMessageType('COffline_GetOfflineLogonTicket_Request', (_message.Message,), {
  'DESCRIPTOR' : _COFFLINE_GETOFFLINELOGONTICKET_REQUEST,
  '__module__' : 'steammessages_offline_pb2'
  # @@protoc_insertion_point(class_scope:COffline_GetOfflineLogonTicket_Request)
  })
_sym_db.RegisterMessage(COffline_GetOfflineLogonTicket_Request)

COffline_GetOfflineLogonTicket_Response = _reflection.GeneratedProtocolMessageType('COffline_GetOfflineLogonTicket_Response', (_message.Message,), {
  'DESCRIPTOR' : _COFFLINE_GETOFFLINELOGONTICKET_RESPONSE,
  '__module__' : 'steammessages_offline_pb2'
  # @@protoc_insertion_point(class_scope:COffline_GetOfflineLogonTicket_Response)
  })
_sym_db.RegisterMessage(COffline_GetOfflineLogonTicket_Response)

COffline_GetUnsignedOfflineLogonTicket_Request = _reflection.GeneratedProtocolMessageType('COffline_GetUnsignedOfflineLogonTicket_Request', (_message.Message,), {
  'DESCRIPTOR' : _COFFLINE_GETUNSIGNEDOFFLINELOGONTICKET_REQUEST,
  '__module__' : 'steammessages_offline_pb2'
  # @@protoc_insertion_point(class_scope:COffline_GetUnsignedOfflineLogonTicket_Request)
  })
_sym_db.RegisterMessage(COffline_GetUnsignedOfflineLogonTicket_Request)

COffline_OfflineLogonTicket = _reflection.GeneratedProtocolMessageType('COffline_OfflineLogonTicket', (_message.Message,), {
  'DESCRIPTOR' : _COFFLINE_OFFLINELOGONTICKET,
  '__module__' : 'steammessages_offline_pb2'
  # @@protoc_insertion_point(class_scope:COffline_OfflineLogonTicket)
  })
_sym_db.RegisterMessage(COffline_OfflineLogonTicket)

COffline_GetUnsignedOfflineLogonTicket_Response = _reflection.GeneratedProtocolMessageType('COffline_GetUnsignedOfflineLogonTicket_Response', (_message.Message,), {
  'DESCRIPTOR' : _COFFLINE_GETUNSIGNEDOFFLINELOGONTICKET_RESPONSE,
  '__module__' : 'steammessages_offline_pb2'
  # @@protoc_insertion_point(class_scope:COffline_GetUnsignedOfflineLogonTicket_Response)
  })
_sym_db.RegisterMessage(COffline_GetUnsignedOfflineLogonTicket_Response)


DESCRIPTOR._options = None

_OFFLINE = _descriptor.ServiceDescriptor(
  name='Offline',
  full_name='Offline',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\202\265\030\030Offline settings service',
  create_key=_descriptor._internal_create_key,
  serialized_start=563,
  serialized_end=982,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetOfflineLogonTicket',
    full_name='Offline.GetOfflineLogonTicket',
    index=0,
    containing_service=None,
    input_type=_COFFLINE_GETOFFLINELOGONTICKET_REQUEST,
    output_type=_COFFLINE_GETOFFLINELOGONTICKET_RESPONSE,
    serialized_options=b'\202\265\030EGet a serialized and signed offline logon ticket for the current user',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetUnsignedOfflineLogonTicket',
    full_name='Offline.GetUnsignedOfflineLogonTicket',
    index=1,
    containing_service=None,
    input_type=_COFFLINE_GETUNSIGNEDOFFLINELOGONTICKET_REQUEST,
    output_type=_COFFLINE_GETUNSIGNEDOFFLINELOGONTICKET_RESPONSE,
    serialized_options=b'\202\265\0309Get an unsigned offline logon ticket for the current user',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_OFFLINE)

DESCRIPTOR.services_by_name['Offline'] = _OFFLINE

Offline = service_reflection.GeneratedServiceType('Offline', (_service.Service,), dict(
  DESCRIPTOR = _OFFLINE,
  __module__ = 'steammessages_offline_pb2'
  ))

Offline_Stub = service_reflection.GeneratedServiceStubType('Offline_Stub', (Offline,), dict(
  DESCRIPTOR = _OFFLINE,
  __module__ = 'steammessages_offline_pb2'
  ))


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: encrypted_app_ticket.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='encrypted_app_ticket.proto',
  package='',
  syntax='proto2',
  serialized_options=b'H\001\220\001\000',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1a\x65ncrypted_app_ticket.proto\"\xad\x01\n\x12\x45ncryptedAppTicket\x12\x19\n\x11ticket_version_no\x18\x01 \x01(\r\x12\x1b\n\x13\x63rc_encryptedticket\x18\x02 \x01(\r\x12\x1c\n\x14\x63\x62_encrypteduserdata\x18\x03 \x01(\r\x12\'\n\x1f\x63\x62_encrypted_appownershipticket\x18\x04 \x01(\r\x12\x18\n\x10\x65ncrypted_ticket\x18\x05 \x01(\x0c\x42\x05H\x01\x90\x01\x00'
)




_ENCRYPTEDAPPTICKET = _descriptor.Descriptor(
  name='EncryptedAppTicket',
  full_name='EncryptedAppTicket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ticket_version_no', full_name='EncryptedAppTicket.ticket_version_no', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='crc_encryptedticket', full_name='EncryptedAppTicket.crc_encryptedticket', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cb_encrypteduserdata', full_name='EncryptedAppTicket.cb_encrypteduserdata', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cb_encrypted_appownershipticket', full_name='EncryptedAppTicket.cb_encrypted_appownershipticket', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='encrypted_ticket', full_name='EncryptedAppTicket.encrypted_ticket', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=31,
  serialized_end=204,
)

DESCRIPTOR.message_types_by_name['EncryptedAppTicket'] = _ENCRYPTEDAPPTICKET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EncryptedAppTicket = _reflection.GeneratedProtocolMessageType('EncryptedAppTicket', (_message.Message,), {
  'DESCRIPTOR' : _ENCRYPTEDAPPTICKET,
  '__module__' : 'encrypted_app_ticket_pb2'
  # @@protoc_insertion_point(class_scope:EncryptedAppTicket)
  })
_sym_db.RegisterMessage(EncryptedAppTicket)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: enums_productinfo.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='enums_productinfo.proto',
  package='',
  syntax='proto2',
  serialized_options=b'H\001\220\001\001\200\265\030\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x17\x65nums_productinfo.proto\x1a\x18steammessages_base.proto*\xfb\x01\n\x14\x45\x43ontentDescriptorID\x12\x36\n2k_EContentDescriptor_FrequentNudityOrSexualContent\x10\x01\x12/\n+k_EContentDescriptor_FrequentViolenceOrGore\x10\x02\x12,\n(k_EContentDescriptor_StrongSexualContent\x10\x03\x12!\n\x1dk_EContentDescriptor_UNUSED_4\x10\x04\x12)\n%k_EContentDescriptor_AnyMatureContent\x10\x05\x42\tH\x01\x90\x01\x01\x80\xb5\x18\x01'
  ,
  dependencies=[steammessages__base__pb2.DESCRIPTOR,])

_ECONTENTDESCRIPTORID = _descriptor.EnumDescriptor(
  name='EContentDescriptorID',
  full_name='EContentDescriptorID',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EContentDescriptor_FrequentNudityOrSexualContent', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EContentDescriptor_FrequentViolenceOrGore', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EContentDescriptor_StrongSexualContent', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EContentDescriptor_UNUSED_4', index=3, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EContentDescriptor_AnyMatureContent', index=4, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=54,
  serialized_end=305,
)
_sym_db.RegisterEnumDescriptor(_ECONTENTDESCRIPTORID)

EContentDescriptorID = enum_type_wrapper.EnumTypeWrapper(_ECONTENTDESCRIPTORID)
k_EContentDescriptor_FrequentNudityOrSexualContent = 1
k_EContentDescriptor_FrequentViolenceOrGore = 2
k_EContentDescriptor_StrongSexualContent = 3
k_EContentDescriptor_UNUSED_4 = 4
k_EContentDescriptor_AnyMatureContent = 5


DESCRIPTOR.enum_types_by_name['EContentDescriptorID'] = _ECONTENTDESCRIPTORID
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



import sys
import time

if sys.version_info >= (3,3):
    _monotonic = time.monotonic
else:
    _monotonic = time.time  # not really monotonic vOv


class ConstantRateLimit(object):
    def __init__(self, times, seconds, exit_wait=False, sleep_func=time.sleep):
        """Context manager for enforcing constant rate on code inside the block .

        `rate = seconds / times`

        :param times: times to execute per...
        :type  times: :class:`int`
        :param seconds: ...seconds
        :type  seconds: :class:`int`
        :param exit_wait: whether to automatically call :meth:`wait` before exiting the block
        :type  exit_wait: :class:`bool`
        :param sleep_func: Sleep function in seconds. Default: :func:`time.sleep`
        :type  sleep_func: :class:`bool`

        Example:

        .. code:: python

            with RateLimiter(1, 5) as r:
                # code taking 1s
                r.wait()  # blocks for 4s
                # code taking 7s
                r.wait()  # doesn't block
                # code taking 1s
                r.wait()  # blocks for 4s
        """
        self.__dict__.update(locals())
        self.rate = float(seconds) / times
        self.sleep_func = sleep_func

    def __enter__(self):
        self._update_ref()
        return self

    def __exit__(self, etype, evalue, traceback):
        if self.exit_wait:
            self.wait()

    def _update_ref(self):
        self._ref = _monotonic() + self.rate

    def wait(self):
        """Blocks until the rate is met"""
        now = _monotonic()
        if now < self._ref:
            delay = max(0, self._ref - now)
            self.sleep_func(delay)
        self._update_ref()


